import PropTypes from 'prop-types';
import React, { useEffect, useRef } from 'react';
import cx from 'clsx';

const DEFAULT_CLASS = 'react-tabs__tab';
const DEFAULT_PROPS = {
  className: DEFAULT_CLASS,
  disabledClassName: `${DEFAULT_CLASS}--disabled`,
  focus: false,
  id: null,
  panelId: null,
  selected: false,
  selectedClassName: `${DEFAULT_CLASS}--selected`,
};

const propTypes = {
  children: PropTypes.oneOfType([
    PropTypes.array,
    PropTypes.object,
    PropTypes.string,
  ]),
  className: PropTypes.oneOfType([
    PropTypes.string,
    PropTypes.array,
    PropTypes.object,
  ]),
  disabled: PropTypes.bool,
  tabIndex: PropTypes.string,
  disabledClassName: PropTypes.string,
  focus: PropTypes.bool, // private
  id: PropTypes.string, // private
  panelId: PropTypes.string, // private
  selected: PropTypes.bool, // private
  selectedClassName: PropTypes.string,
  tabRef: PropTypes.func,
};

const Tab = (props) => {
  let nodeRef = useRef();
  const checkFocus = () => {
    const { selected, focus } = props;
    if (selected && focus) {
      nodeRef.current.focus();
    }
  };
  useEffect(() => {
    checkFocus();
  });
  const {
    children,
    className,
    disabled,
    disabledClassName,
    focus, // unused
    id,
    panelId,
    selected,
    selectedClassName,
    tabIndex,
    tabRef,
    ...attributes
  } = props;

  return (
    <li
      {...attributes}
      className={cx(className, {
        [selectedClassName]: selected,
        [disabledClassName]: disabled,
      })}
      ref={(node) => {
        nodeRef.current = node;
        if (tabRef) tabRef(node);
      }}
      role="tab"
      id={id}
      aria-selected={selected ? 'true' : 'false'}
      aria-disabled={disabled ? 'true' : 'false'}
      aria-controls={panelId}
      tabIndex={tabIndex || (selected ? '0' : null)}
      data-rttab
    >
      {children}
    </li>
  );
};
Tab.propTypes = propTypes;

Tab.tabsRole = 'Tab';
Tab.defaultProps = DEFAULT_PROPS;
export default Tab;
